<?php
//
// 2020-27-04  Added ability to select icons sets (Font Awesome, Multi-Color, Universal 100 and Free Outline 300) to load. 
// Unchecked sets are not loaded, and will be unavailable during page building and viewing. 
// Currently asking for at least one checked box. - TH
//
if (self::WPORG || ds_icon_expansion_has_license_key()) { 

    // Establish (if first run) or load (based on previously selected options) icon sets to use
    $fa_icons = get_option( 'agsdi_fa_icons' );     // Font Awesome
    if ( !$fa_icons || $fa_icons == false ) {
        add_option( 'agsdi_fa_icons', 'yes', '', 'yes' );
        $fa_icons = "yes";
    }
    $mc_icons = get_option( 'agsdi_mc_icons' );     // Multi-Color
    if ( !$mc_icons || $mc_icons == false ) {
        add_option( 'agsdi_mc_icons', 'yes', '', 'yes' );
        $mc_icons = "yes";
    }
    $ui_icons = get_option( 'agsdi_ui_icons' );    // Universal 100
    if ( !$ui_icons || $ui_icons == false ) {
        add_option( 'agsdi_ui_icons', 'yes', '', 'yes' );
        $ui_icons = "yes";
    }
    $fo_icons = get_option( 'agsdi_fo_icons' );     // Free Outline 300
    if ( !$fo_icons || $fo_icons == false ) {
        add_option( 'agsdi_fo_icons', 'yes', '', 'yes' );
        $fo_icons = "yes";
    } 
?>

    <div id="ds_icon_expansion-settings-container">
    <div id="ds_icon_expansion-settings">

        <div id="ds_icon_expansion-settings-header">
            <div class="ds_icon_expansion-settings-logo">
                <h1> <?php echo esc_html__(self::PLUGIN_NAME, 'ds-icon-epxansion'); ?></h1>
            </div>
            <div id="ds_icon_expansion-settings-header-links">
                <a id="ds_icon_expansion-settings-header-link-support"
                   href="https://support.aspengrovestudios.com/article/418-wp-and-divi-icons"
                   target="_blank"><?php esc_html_e('Support', 'ds-icon-expansion'); ?></a>
            </div>
        </div>

        <ul id="ds_icon_expansion-settings-tabs">
            <li><a href="#icon-sets"><?php esc_html_e('Performance', 'ds-icon-expansion'); ?></a></li>
            <?php if (!self::WPORG) { ?>
            <li><a href="#icons"><?php esc_html_e('Multi-Color Icons', 'ds-icon-expansion'); ?></a></li>
            <?php } ?>
            <li class="ds_icon_expansion-settings-active"><a href="#instructions"><?php esc_html_e('About & Instructions', 'ds-icon-expansion'); ?></a></li>
            <li><a href="#license"><?php esc_html_e('License Key', 'ds-icon-expansion'); ?></a></li>
        </ul>

        <div id="ds_icon_expansion-settings-tabs-content">
            
        <?php 
        // Handle the "Performance" tab form processing (select icon sets to load and use)
            if (!empty($_POST) && !empty($_POST['agsdi-icon-sets']) ) {
                // Icon sets form was posted (agsdi-icon-sets hidden form field is present)
                // Don't update stored settings in case user unchecked every option
                $none_checked = empty($_POST['agsdi-fa-icons']) && empty($_POST['agsdi-mc-icons']) && empty($_POST['agsdi-ui-icons']) && empty($_POST['agsdi-fo-icons']);
                $iconSetValidationError = false;
    
                if (!$none_checked) {
                    // Update icons sets to use based on checked status
                    if ( !empty( $_POST['agsdi-fa-icons'] ) ) {
                        update_option( 'agsdi_fa_icons', 'yes', 'yes' );
                        $fa_icons = "yes";
                    } else {
                        update_option( 'agsdi_fa_icons', 'no', 'yes' );
                        $fa_icons = "no";
                    }
                    if ( !empty( $_POST['agsdi-mc-icons'] ) ) {
                        update_option( 'agsdi_mc_icons', 'yes', 'yes' );
                        $mc_icons = "yes";
                    } else {
                        update_option( 'agsdi_mc_icons', 'no', 'yes' );
                        $mc_icons = "no";
                    }
                    if ( !empty( $_POST['agsdi-ui-icons'] ) ) {
                        update_option( 'agsdi_ui_icons', 'yes', 'yes' );
                        $ui_icons = "yes";
                    } else {
                        update_option( 'agsdi_ui_icons', 'no', 'yes' );
                        $ui_icons = "no";
                    }
                    if ( !empty( $_POST['agsdi-fo-icons'] ) ) {
                        update_option( 'agsdi_fo_icons', 'yes', 'yes' );
                        $fo_icons = "yes";
                    } else {
                        update_option( 'agsdi_fo_icons', 'no', 'yes' );
                        $fo_icons = "no";
                    }
                } else {
                    $iconSetValidationError = true;
                }
            }
        // Show available icons sets. Allow user to select sets to use on site. 
        // Unselected sets will not load and will not be availble when building. ?>
            <div id="ds_icon_expansion-settings-icon-sets">
                <form id="agsdi-icon-sets" method="post">
                    <h3><?php echo(esc_html__('Choose Icon Set(s) to Load', 'ds-icon-expansion')); ?></h3>
      	            <?php if (!empty($iconSetValidationError)) { ?>
                        <p id="agsdi-icon-sets-error"><?php echo(esc_html__('You must select at least one icon set to load. Your previous selections have been restored.', 'ds-icon-expansion')); ?></p>
    	            <?php } ?>
                    <p><?php echo sprintf(
                        esc_html__('By default, WP and Divi Icons will load all available icon sets for use. You can uncheck icon sets that you do not wish to load. This can help improve page builder performance by not including icons sets you do not use on your site.', 'ds-icon-expansion'),
                        esc_html(self::PLUGIN_NAME),
                        '<span data-icon="agsdix-sao-design" class="agsdi-icon"></span>'
                        ); ?>
                    </p>
            	    <div>
            		    <input type="checkbox" name="agsdi-fa-icons" value="<?php echo(esc_attr($fa_icons));?>"<?php echo($fa_icons == 'yes' ? ' checked="checked"' : ''); ?>>
                        <label for="agsdi-fa-icons">Font Awesome Icon Pack</label><br>
		                <input type="checkbox" name="agsdi-mc-icons" value="<?php echo(esc_attr($mc_icons));?>"<?php echo($mc_icons == 'yes' ? ' checked="checked"' : ''); ?>>
                        <label for="agsdi-mc-icons">Multi-Color Icon Pack</label><br>
		                <input type="checkbox" name="agsdi-ui-icons" value="<?php echo(esc_attr($ui_icons));?>"<?php echo($ui_icons == 'yes' ? ' checked="checked"' : ''); ?>>
                        <label for="agsdi-ui-icons">100 Universal Icon Pack</label><br>
		                <input type="checkbox" name="agsdi-fo-icons" value="<?php echo(esc_attr($fo_icons));?>"<?php echo($fo_icons == 'yes' ? ' checked="checked"' : ''); ?>>
                        <label for="agsdi-fo-icons">300+ Free Outline Icon Pack</label><br>
                        <input type="hidden" name="agsdi-icon-sets" id="agsdi-icon-sets" value="yes">
		                <button class="ds_icon_button-primary"><?php echo(esc_html__('Save', 'ds-icon-expansion')); ?></button>
	                </div>
                </form>
            </div>

            <div id="ds_icon_expansion-settings-icons">
                <h3><?php echo(esc_html__('Multi-Color Icons', 'ds-icon-expansion')); ?></h3>

                <?php
                if (!empty($_POST) && empty($_POST['agsdi-icon-sets'])) {
                    // "Multi-Color Icons" tab form was posted (agsdi-icon-sets hidden form field is not present)
                    $colorSchemes = array();
                    if (isset($_POST['agsdi_colors']) && is_array($_POST['agsdi_colors'])) {
                        foreach ($_POST['agsdi_colors'] as $colorSchemeId => $colorScheme) {
                            if ($colorSchemeId == 'new') {
                                if (count($_POST['agsdi_colors']) == 1) {
                                    $colorSchemeId = 1;
                                } else {
                                    $allColorSchemeIds = array_keys($_POST['agsdi_colors']);
                                    rsort($allColorSchemeIds);
                                    foreach ($allColorSchemeIds as $id) {
                                        if (is_numeric($id) && $id % 1 == 0 && $id > 0) {
                                            $colorSchemeId = ++$id;
                                            break;
                                        }
                                    }

                                    if ($colorSchemeId == 'new') {
                                        $colorSchemeValidationError = true;
                                        break;
                                    }
                                }
                            }

                            $colorScheme = array_map('sanitize_hex_color', $colorScheme);

                            if (count($colorScheme) != 3 || empty($colorScheme[0]) || empty($colorScheme[1]) || empty($colorScheme[2])) {
                                $colorSchemeValidationError = true;
                                break;
                            } else {
                                $colorSchemes[$colorSchemeId] = array(
                                    substr($colorScheme[0], 1),
                                    substr($colorScheme[1], 1),
                                    substr($colorScheme[2], 1)
                                );
                            }
                        }
                    }

                    if (empty($colorSchemeValidationError)) {
                        if (empty($colorSchemes)) {
                            delete_option('aspengrove_icons_colors');
                        } else {
                            update_option('aspengrove_icons_colors', $colorSchemes);
                        }

                        foreach ($colorSchemes as $colorSchemeId => $colorScheme) {
                            AGS_Divi_Icons_Pro::colorizeSvg($colorScheme, $colorSchemeId);
                        }

                        $colorSchemeIds = array_keys($colorSchemes);
                        AGS_Divi_Icons_Pro::generateMultiColorCss($colorSchemeIds);

                        AGS_Divi_Icons_Pro::cleanupMultiColorSvgs($colorSchemeIds);
                    }
                } else {
                    $colorSchemes = get_option('aspengrove_icons_colors', array());
                }

                ?>
                <script>
                    var agsdi_color_preview_icons = <?php echo(json_encode(AGS_Divi_Icons::getMultiColorIcons())); ?>;
                </script>
                <form id="agsdi-color-schemes" method="post">
                    <?php if (!empty($colorSchemeValidationError)) { ?>
                        <p id="agsdi-color-schemes-error"><?php echo(esc_html__('The color schemes were not saved due to validation error(s).', 'ds-icon-expansion')); ?></p>
                    <?php } ?>

                    <p id="agsdi-color-schemes-none"<?php if (!empty($colorSchemes)) { ?> class="hidden"<?php } ?>><?php echo(esc_html__('No color schemes are currently defined.', 'ds-icon-expansion')); ?></p>
                    <?php
                    foreach ($colorSchemes as $colorSchemeId => $colorScheme) {
                        ?>
                        <div data-colors-id="<?php echo(esc_attr($colorSchemeId)); ?>">
                            <div class="agsdi-color-preview"></div>
                            <input type="text" name="agsdi_colors[<?php echo(esc_attr($colorSchemeId)); ?>][0]"
                                   value="#<?php echo(esc_attr($colorScheme[0])); ?>">
                            <input type="text" name="agsdi_colors[<?php echo(esc_attr($colorSchemeId)); ?>][1]"
                                   value="#<?php echo(esc_attr($colorScheme[1])); ?>">
                            <input type="text" name="agsdi_colors[<?php echo(esc_attr($colorSchemeId)); ?>][2]"
                                   value="#<?php echo(esc_attr($colorScheme[2])); ?>">
                            <button class="agsdi-colors-remove button-secondary"><?php echo(esc_html__('Remove', 'ds-icon-expansion')); ?></button>
                        </div>
                        <?php
                    }
                    ?>
                    <div id="agsdi-color-schemes-buttons">
                        <?php wp_nonce_field('agsdi-color-schemes-save'); ?>
                        <button id="agsdi-colors-add" type="button" class="ds_icon_button-secondary"><?php echo(esc_html__('Add Color Scheme', 'ds-icon-expansion')); ?></button>
                        <button class="ds_icon_button-primary"><?php echo(esc_html__('Save', 'ds-icon-expansion')); ?></button>
                    </div>
                </form>
            </div>

            <div id="ds_icon_expansion-settings-instructions" class="ds_icon_expansion-settings-active">
                <h3><?php echo(esc_html__('Instructions', 'ds-icon-expansion')); ?></h3>
                <p><?php echo sprintf(
                        esc_html__('Easily insert one of the 2600+ icons provided by %s when using the WordPress visual editor to create and edit posts, pages, and other content! Simply click on the %s icon in the editor\'s toolbar to open the icon insertion window.', 'ds-icon-expansion'),
                        esc_html(self::PLUGIN_NAME),
                        '<span data-icon="agsdix-sao-design" class="agsdi-icon"></span>'
                    ); ?>
                </p>
                <p><?php echo sprintf(
                        esc_html__('If you use the %sDivi or Extra theme%s or the %sDivi Builder%s, you can also use the 2600+ icons provided by %s anywhere that the Divi Builder allows you to specify an icon, such as in Buttons, Blurbs, and much more! Works in both the Divi Builder and the Visual Builder.', 'ds-icon-expansion'),
                        '<a href="http://www.elegantthemes.com/affiliates/idevaffiliate.php?id=32248_0_1_10" target="_blank">',
                        '</a>',
                        '<a href="http://www.elegantthemes.com/affiliates/idevaffiliate.php?id=32248_0_1_10" target="_blank">',
                        '</a>',
                        esc_html(self::PLUGIN_NAME)
                    ); ?>
                </p>

                <hr>

                <h3><?php echo(esc_html__('Check out these products too!', 'ds-icon-expansion')); ?></h3>
                <ul id="ds_icon_expansion-settings-products">
                    <?php
                    foreach (self::getCreditPromos('admin-page', true) as $promo) {
                        echo('<li>' . $promo . '</li>');
                    }
                    ?>
                </ul>

            </div>

            <?php if (!self::WPORG) { ?>
                <div id="ds_icon_expansion-settings-license">
                    <?php ds_icon_expansion_license_key_box();; ?>
                </div>
            <?php } ?>

        </div>
    </div>

    <p><em><?php esc_html_e('Divi is a registered trademark of Elegant Themes, Inc. This product is not affiliated with nor endorsed by Elegant Themes. Links to the Elegant Themes website on this page are affiliate links.', 'ds-icon-expansion');?></em></p>

    <script>
        var ags_testify_tabs_navigate = function () {
            jQuery('#ds_icon_expansion-settings-tabs-content > div, #ds_icon_expansion-settings-tabs > li').removeClass('ds_icon_expansion-settings-active');
            jQuery('#ds_icon_expansion-settings-' + location.hash.substr(1)).addClass('ds_icon_expansion-settings-active');
            jQuery('#ds_icon_expansion-settings-tabs > li:has(a[href="' + location.hash + '"])').addClass('ds_icon_expansion-settings-active');
        };

        if (location.hash) {
            ags_testify_tabs_navigate();
        }

        jQuery(window).on('hashchange', ags_testify_tabs_navigate);
    </script>

    <?php
    @include(self::$pluginDir . 'build/test.php');

} else {
    ds_icon_expansion_activate_page();
}
